@@ -82,17 +82,8 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "../agraph/grammar.y"
+#line 17 "../agraph/grammar.y"
 
-/*
-    This software may only be used by you under license from AT&T Corp.
-    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
-    AT&T's Internet website having the URL:
-    <http://www.research.att.com/sw/tools/graphviz/license/source.html>
-    If you received this software without first entering into a license
-    with AT&T, you have an infringing copy of this software and cannot use
-    it without violating AT&T's intellectual property rights.
-*/
 
 #include <stdio.h>  /* SAFE */
 #include <aghdr.h>	/* SAFE */
@@ -162,14 +153,14 @@ static Agraph_t *G;
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 66 "../agraph/grammar.y"
+#line 73 "../agraph/grammar.y"
 typedef union YYSTYPE {
 			int				i;
 			char			*str;
 			struct Agnode_s	*n;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 173 "y.tab.c"
+#line 164 "y.tab.c"
 # define aagstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -181,7 +172,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 185 "y.tab.c"
+#line 176 "y.tab.c"
 
 #if ! defined (aagoverflow) || YYERROR_VERBOSE
 
@@ -374,13 +365,13 @@ static const aagsigned_char aagrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char aagrline[] =
 {
-       0,    83,    83,    84,    85,    88,    90,    93,    93,    95,
-      95,    97,    97,    99,    99,   101,   101,   103,   103,   105,
-     106,   109,   113,   113,   115,   115,   116,   120,   120,   122,
-     123,   124,   127,   128,   131,   132,   133,   136,   137,   140,
-     140,   142,   144,   145,   147,   150,   150,   152,   155,   158,
-     161,   161,   164,   165,   166,   169,   169,   169,   171,   172,
-     175,   176
+       0,    90,    90,    91,    92,    95,    97,   100,   100,   102,
+     102,   104,   104,   106,   106,   108,   108,   110,   110,   112,
+     113,   116,   120,   120,   122,   122,   123,   127,   127,   129,
+     130,   131,   134,   135,   138,   139,   140,   143,   144,   147,
+     147,   149,   151,   152,   154,   157,   157,   159,   162,   165,
+     168,   168,   171,   172,   173,   176,   176,   176,   178,   179,
+     182,   183
 };
 #endif
 
@@ -1131,172 +1122,172 @@ aagreduce:
   switch (aagn)
     {
         case 2:
-#line 83 "../agraph/grammar.y"
+#line 90 "../agraph/grammar.y"
     {endgraph();}
     break;
 
   case 3:
-#line 84 "../agraph/grammar.y"
+#line 91 "../agraph/grammar.y"
     {if (G) {agclose(G); G = Ag_G_global = NIL(Agraph_t*);}}
     break;
 
   case 6:
-#line 90 "../agraph/grammar.y"
+#line 97 "../agraph/grammar.y"
     {startgraph(aagvsp[0].str,aagvsp[-1].i,aagvsp[-2].i);}
     break;
 
   case 7:
-#line 93 "../agraph/grammar.y"
+#line 100 "../agraph/grammar.y"
     {aagval.str=aagvsp[0].str;}
     break;
 
   case 8:
-#line 93 "../agraph/grammar.y"
+#line 100 "../agraph/grammar.y"
     {aagval.str=0;}
     break;
 
   case 9:
-#line 95 "../agraph/grammar.y"
+#line 102 "../agraph/grammar.y"
     {aagval.i=1;}
     break;
 
   case 10:
-#line 95 "../agraph/grammar.y"
+#line 102 "../agraph/grammar.y"
     {aagval.i=0;}
     break;
 
   case 11:
-#line 97 "../agraph/grammar.y"
+#line 104 "../agraph/grammar.y"
     {aagval.i = 0;}
     break;
 
   case 12:
-#line 97 "../agraph/grammar.y"
+#line 104 "../agraph/grammar.y"
     {aagval.i = 1;}
     break;
 
   case 21:
-#line 110 "../agraph/grammar.y"
+#line 117 "../agraph/grammar.y"
     {if (aagvsp[-1].i) endedge(); else endnode();}
     break;
 
   case 24:
-#line 115 "../agraph/grammar.y"
+#line 122 "../agraph/grammar.y"
     {bufferedges();}
     break;
 
   case 25:
-#line 115 "../agraph/grammar.y"
+#line 122 "../agraph/grammar.y"
     {aagval.i = 1;}
     break;
 
   case 26:
-#line 116 "../agraph/grammar.y"
+#line 123 "../agraph/grammar.y"
     {aagval.i = 0;}
     break;
 
   case 29:
-#line 122 "../agraph/grammar.y"
+#line 129 "../agraph/grammar.y"
     {appendnode(aagvsp[0].str,NIL(char*),NIL(char*));}
     break;
 
   case 30:
-#line 123 "../agraph/grammar.y"
+#line 130 "../agraph/grammar.y"
     {appendnode(aagvsp[-2].str,aagvsp[0].str,NIL(char*));}
     break;
 
   case 31:
-#line 124 "../agraph/grammar.y"
+#line 131 "../agraph/grammar.y"
     {appendnode(aagvsp[-4].str,aagvsp[-2].str,aagvsp[0].str);}
     break;
 
   case 32:
-#line 127 "../agraph/grammar.y"
+#line 134 "../agraph/grammar.y"
     {attrstmt(aagvsp[-2].i,aagvsp[-1].str);}
     break;
 
   case 33:
-#line 128 "../agraph/grammar.y"
+#line 135 "../agraph/grammar.y"
     {attrstmt(T_graph,NIL(char*));}
     break;
 
   case 34:
-#line 131 "../agraph/grammar.y"
+#line 138 "../agraph/grammar.y"
     {aagval.i = T_graph;}
     break;
 
   case 35:
-#line 132 "../agraph/grammar.y"
+#line 139 "../agraph/grammar.y"
     {aagval.i = T_node;}
     break;
 
   case 36:
-#line 133 "../agraph/grammar.y"
+#line 140 "../agraph/grammar.y"
     {aagval.i = T_edge;}
     break;
 
   case 37:
-#line 136 "../agraph/grammar.y"
+#line 143 "../agraph/grammar.y"
     {aagval.str = aagvsp[-1].str;}
     break;
 
   case 38:
-#line 137 "../agraph/grammar.y"
+#line 144 "../agraph/grammar.y"
     {aagval.str = NIL(char*); }
     break;
 
   case 47:
-#line 152 "../agraph/grammar.y"
+#line 159 "../agraph/grammar.y"
     {appendattr(aagvsp[-2].str,aagvsp[0].str);}
     break;
 
   case 48:
-#line 155 "../agraph/grammar.y"
+#line 162 "../agraph/grammar.y"
     {appendattr(aagvsp[0].str,NIL(char*));}
     break;
 
   case 50:
-#line 161 "../agraph/grammar.y"
+#line 168 "../agraph/grammar.y"
     {opensubg(aagvsp[0].str);}
     break;
 
   case 51:
-#line 161 "../agraph/grammar.y"
+#line 168 "../agraph/grammar.y"
     {closesubg();}
     break;
 
   case 52:
-#line 164 "../agraph/grammar.y"
+#line 171 "../agraph/grammar.y"
     {aagval.str=aagvsp[0].str;}
     break;
 
   case 53:
-#line 165 "../agraph/grammar.y"
+#line 172 "../agraph/grammar.y"
     {aagval.str=NIL(char*);}
     break;
 
   case 54:
-#line 166 "../agraph/grammar.y"
+#line 173 "../agraph/grammar.y"
     {aagval.str=NIL(char*);}
     break;
 
   case 58:
-#line 171 "../agraph/grammar.y"
+#line 178 "../agraph/grammar.y"
     {aagval.str = aagvsp[0].str;}
     break;
 
   case 59:
-#line 172 "../agraph/grammar.y"
+#line 179 "../agraph/grammar.y"
     {aagval.str = aagvsp[0].str;}
     break;
 
   case 60:
-#line 175 "../agraph/grammar.y"
+#line 182 "../agraph/grammar.y"
     {aagval.str = aagvsp[0].str;}
     break;
 
   case 61:
-#line 177 "../agraph/grammar.y"
+#line 184 "../agraph/grammar.y"
     {aagval.str = concat(aagvsp[-2].str,aagvsp[0].str); agstrfree(G,aagvsp[-2].str); agstrfree(G,aagvsp[0].str);}
     break;
 
@@ -1304,7 +1295,7 @@ aagreduce:
     }
 
 /* Line 1000 of yacc.c.  */
-#line 1308 "y.tab.c"
+#line 1299 "y.tab.c"
 
   aagvsp -= aaglen;
   aagssp -= aaglen;
@@ -1529,7 +1520,7 @@ aagreturn:
 }
 
 
-#line 179 "../agraph/grammar.y"
+#line 186 "../agraph/grammar.y"
 
 
 #define NILitem  NIL(item*)
