@@ -1,6 +1,6 @@
 #! /bin/sh
 
-autoreconf -v --install || exit 1
+autoreconf -v --install --force || exit 1
 
 # ensure config/depcomp exists even if still using automake-1.4
 # otherwise "make dist" fails.
@@ -13,7 +13,7 @@ patch -N -p0 <ltmain.sh.patch
                                                                                 
 # ensure COPYING is based on LICENSE.html
 rm -f COPYING
-lynx -dump LICENSE.html >COPYING
+lynx -dump CPL.html >COPYING
 
 #./configure "$@"
 
