@@ -78,17 +78,8 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "../graph/parser.y"
+#line 17 "../graph/parser.y"
 
-/*
-    This software may only be used by you under license from AT&T Corp.
-    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
-    AT&T's Internet website having the URL:
-    <http://www.research.att.com/sw/tools/graphviz/license/source.html>
-    If you received this software without first entering into a license
-    with AT&T, you have an infringing copy of this software and cannot use
-    it without violating AT&T's intellectual property rights.
-*/
 
 #include	"libgraph.h"
 
@@ -107,16 +98,6 @@ static Agedge_t		*E;
 static objstack_t	*SP;
 static Agraph_t		*Gstack[32];
 static int			GSP;
-static int			override;
-
-/* agoverride:
- * If override == 1, initial attr_stmt is ignored if the attribute is
- *                   already defined.
- */
-void agoverride(int ov)
-{
-  override = (ov > 0 ? ov : 0);
-}
 
 static void push_subg(Agraph_t *g)
 {
@@ -340,7 +321,7 @@ static void attr_set(char *name, char *value)
 			ap = agfindattr(G->proto->n,name);
 			if (ap == NULL)
 				ap = agnodeattr(AG.parsed_g,name,defval);
-            else if (override && In_decl)
+            else if (ap->fixed && In_decl)
               return;
 			agxset(N,ap->index,value);
 			break;
@@ -348,8 +329,28 @@ static void attr_set(char *name, char *value)
 			ap = agfindattr(G->proto->e,name);
 			if (ap == NULL)
 				ap = agedgeattr(AG.parsed_g,name,defval);
-            else if (override && In_decl)
+            else if (ap->fixed && In_decl)
               return;
+			if (ap->index == HEADX) {
+				char* cp = strchr(value,':');
+				if (cp) {
+					*cp++ = '\0';
+					if (cp[0]) {
+						if (!headsubsym) headsubsym = initEdgeSym(E,HEADSUB_ID);
+						agxset(E,headsubsym->index,cp);
+					}
+				}
+			}
+			else if (ap->index == TAILX) {
+				char* cp = strchr(value,':');
+				if (cp) {
+					*cp++ = '\0';
+					if (cp[0]) {
+						if (!tailsubsym) tailsubsym = initEdgeSym(E,TAILSUB_ID);
+						agxset(E,tailsubsym->index,cp);
+					}
+				}
+			}
 			agxset(E,ap->index,value);
 			break;
 		case 0:		/* default */
@@ -357,7 +358,7 @@ static void attr_set(char *name, char *value)
 			ap = agfindattr(G,name);
 			if (ap == NULL) 
 				ap = agraphattr(AG.parsed_g,name,defval);
-            else if (override && In_decl)
+            else if (ap->fixed && In_decl)
               return;
 			agxset(G,ap->index,value);
 			break;
@@ -399,7 +400,7 @@ concat (char* s1, char* s2)
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 307 "../graph/parser.y"
+#line 324 "../graph/parser.y"
 typedef union YYSTYPE {
 			int					i;
 			char				*str;
@@ -407,7 +408,7 @@ typedef union YYSTYPE {
 			struct Agnode_t		*n;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 411 "y.tab.c"
+#line 412 "y.tab.c"
 # define agstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -419,7 +420,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 423 "y.tab.c"
+#line 424 "y.tab.c"
 
 #if ! defined (agoverflow) || YYERROR_VERBOSE
 
@@ -615,13 +616,13 @@ static const agsigned_char agrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short agrline[] =
 {
-       0,   325,   325,   324,   328,   335,   338,   338,   341,   343,
-     345,   347,   351,   353,   355,   359,   360,   363,   364,   367,
-     370,   371,   374,   377,   381,   382,   386,   387,   390,   391,
-     394,   395,   396,   399,   400,   401,   402,   405,   407,   411,
-     426,   429,   430,   431,   435,   434,   441,   443,   440,   448,
-     450,   447,   456,   458,   457,   460,   463,   462,   468,   469,
-     469,   470,   470,   471,   474,   484,   485,   488,   489
+       0,   342,   342,   341,   345,   352,   355,   355,   358,   360,
+     362,   364,   368,   370,   372,   376,   377,   380,   381,   384,
+     387,   388,   391,   394,   398,   399,   403,   404,   407,   408,
+     411,   412,   413,   416,   417,   418,   419,   422,   424,   428,
+     443,   446,   447,   448,   452,   451,   458,   460,   457,   465,
+     467,   464,   473,   475,   474,   477,   480,   479,   485,   486,
+     486,   487,   487,   488,   491,   501,   502,   505,   506
 };
 #endif
 
@@ -1381,17 +1382,17 @@ agreduce:
   switch (agn)
     {
         case 2:
-#line 325 "../graph/parser.y"
+#line 342 "../graph/parser.y"
     {begin_graph(agvsp[0].str); agstrfree(agvsp[0].str);}
     break;
 
   case 3:
-#line 327 "../graph/parser.y"
+#line 344 "../graph/parser.y"
     {AG.accepting_state = TRUE; end_graph();}
     break;
 
   case 4:
-#line 329 "../graph/parser.y"
+#line 346 "../graph/parser.y"
     {
 					if (AG.parsed_g)
 						agclose(AG.parsed_g);
@@ -1401,87 +1402,87 @@ agreduce:
     break;
 
   case 5:
-#line 335 "../graph/parser.y"
+#line 352 "../graph/parser.y"
     {AG.parsed_g = NULL;}
     break;
 
   case 6:
-#line 338 "../graph/parser.y"
+#line 355 "../graph/parser.y"
     {agval.str=agvsp[0].str;}
     break;
 
   case 7:
-#line 338 "../graph/parser.y"
+#line 355 "../graph/parser.y"
     {agval.str=0;}
     break;
 
   case 8:
-#line 342 "../graph/parser.y"
+#line 359 "../graph/parser.y"
     {Agraph_type = AGRAPH; AG.edge_op = "--";}
     break;
 
   case 9:
-#line 344 "../graph/parser.y"
+#line 361 "../graph/parser.y"
     {Agraph_type = AGRAPHSTRICT; AG.edge_op = "--";}
     break;
 
   case 10:
-#line 346 "../graph/parser.y"
+#line 363 "../graph/parser.y"
     {Agraph_type = AGDIGRAPH; AG.edge_op = "->";}
     break;
 
   case 11:
-#line 348 "../graph/parser.y"
+#line 365 "../graph/parser.y"
     {Agraph_type = AGDIGRAPHSTRICT; AG.edge_op = "->";}
     break;
 
   case 12:
-#line 352 "../graph/parser.y"
+#line 369 "../graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 13:
-#line 354 "../graph/parser.y"
+#line 371 "../graph/parser.y"
     {Current_class = TAG_NODE; N = G->proto->n;}
     break;
 
   case 14:
-#line 356 "../graph/parser.y"
+#line 373 "../graph/parser.y"
     {Current_class = TAG_EDGE; E = G->proto->e;}
     break;
 
   case 23:
-#line 378 "../graph/parser.y"
+#line 395 "../graph/parser.y"
     {attr_set(agvsp[-2].str,agvsp[0].str); agstrfree(agvsp[-2].str); agstrfree(agvsp[0].str);}
     break;
 
   case 25:
-#line 383 "../graph/parser.y"
+#line 400 "../graph/parser.y"
     {attr_set(agvsp[0].str,"true"); agstrfree(agvsp[0].str); }
     break;
 
   case 32:
-#line 396 "../graph/parser.y"
+#line 413 "../graph/parser.y"
     {agerror("syntax error, statement skipped");}
     break;
 
   case 36:
-#line 402 "../graph/parser.y"
+#line 419 "../graph/parser.y"
     {}
     break;
 
   case 37:
-#line 406 "../graph/parser.y"
+#line 423 "../graph/parser.y"
     {Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 38:
-#line 408 "../graph/parser.y"
+#line 425 "../graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 39:
-#line 412 "../graph/parser.y"
+#line 429 "../graph/parser.y"
     {
 					objport_t		rv;
 					rv.obj = agvsp[-1].n;
@@ -1497,114 +1498,114 @@ agreduce:
     break;
 
   case 40:
-#line 426 "../graph/parser.y"
+#line 443 "../graph/parser.y"
     {agval.n = bind_node(agvsp[0].str); agstrfree(agvsp[0].str);}
     break;
 
   case 42:
-#line 430 "../graph/parser.y"
+#line 447 "../graph/parser.y"
     {Port=agvsp[0].str;}
     break;
 
   case 43:
-#line 431 "../graph/parser.y"
+#line 448 "../graph/parser.y"
     {Port=agvsp[-2].str;Subport=agvsp[0].str;}
     break;
 
   case 44:
-#line 435 "../graph/parser.y"
+#line 452 "../graph/parser.y"
     {Current_class = TAG_NODE; N = (Agnode_t*)(agvsp[0].obj.obj);}
     break;
 
   case 45:
-#line 437 "../graph/parser.y"
+#line 454 "../graph/parser.y"
     {free(agvsp[-2].obj.port);Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 46:
-#line 441 "../graph/parser.y"
+#line 458 "../graph/parser.y"
     {begin_edgestmt(agvsp[0].obj);}
     break;
 
   case 47:
-#line 443 "../graph/parser.y"
+#line 460 "../graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 48:
-#line 446 "../graph/parser.y"
+#line 463 "../graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 49:
-#line 448 "../graph/parser.y"
+#line 465 "../graph/parser.y"
     {begin_edgestmt(agvsp[0].obj);}
     break;
 
   case 50:
-#line 450 "../graph/parser.y"
+#line 467 "../graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 51:
-#line 453 "../graph/parser.y"
+#line 470 "../graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 52:
-#line 456 "../graph/parser.y"
+#line 473 "../graph/parser.y"
     {mid_edgestmt(agvsp[0].obj);}
     break;
 
   case 53:
-#line 458 "../graph/parser.y"
+#line 475 "../graph/parser.y"
     {mid_edgestmt(agvsp[0].obj);}
     break;
 
   case 55:
-#line 461 "../graph/parser.y"
+#line 478 "../graph/parser.y"
     {mid_edgestmt(agvsp[0].obj);}
     break;
 
   case 56:
-#line 463 "../graph/parser.y"
+#line 480 "../graph/parser.y"
     {mid_edgestmt(agvsp[0].obj);}
     break;
 
   case 58:
-#line 468 "../graph/parser.y"
+#line 485 "../graph/parser.y"
     {agval.obj = pop_gobj();}
     break;
 
   case 59:
-#line 469 "../graph/parser.y"
+#line 486 "../graph/parser.y"
     { anonsubg(); }
     break;
 
   case 60:
-#line 469 "../graph/parser.y"
+#line 486 "../graph/parser.y"
     {agval.obj = pop_gobj();}
     break;
 
   case 61:
-#line 470 "../graph/parser.y"
+#line 487 "../graph/parser.y"
     { anonsubg(); }
     break;
 
   case 62:
-#line 470 "../graph/parser.y"
+#line 487 "../graph/parser.y"
     {agval.obj = pop_gobj();}
     break;
 
   case 63:
-#line 471 "../graph/parser.y"
+#line 488 "../graph/parser.y"
     {agval.obj = pop_gobj();}
     break;
 
   case 64:
-#line 475 "../graph/parser.y"
+#line 492 "../graph/parser.y"
     { Agraph_t	 *subg;
 				if ((subg = agfindsubg(AG.parsed_g,agvsp[0].str))) aginsert(G,subg);
 				else subg = agsubg(G,agvsp[0].str); 
@@ -1615,22 +1616,22 @@ agreduce:
     break;
 
   case 65:
-#line 484 "../graph/parser.y"
+#line 501 "../graph/parser.y"
     {agval.str = agvsp[0].str; }
     break;
 
   case 66:
-#line 485 "../graph/parser.y"
+#line 502 "../graph/parser.y"
     {agval.str = agvsp[0].str; }
     break;
 
   case 67:
-#line 488 "../graph/parser.y"
+#line 505 "../graph/parser.y"
     {agval.str = agvsp[0].str; }
     break;
 
   case 68:
-#line 489 "../graph/parser.y"
+#line 506 "../graph/parser.y"
     {agval.str = concat(agvsp[-2].str,agvsp[0].str); agstrfree(agvsp[-2].str); agstrfree(agvsp[0].str);}
     break;
 
@@ -1638,7 +1639,7 @@ agreduce:
     }
 
 /* Line 1000 of yacc.c.  */
-#line 1642 "y.tab.c"
+#line 1643 "y.tab.c"
 
   agvsp -= aglen;
   agssp -= aglen;
@@ -1863,7 +1864,7 @@ agreturn:
 }
 
 
-#line 491 "../graph/parser.y"
+#line 508 "../graph/parser.y"
 
 #ifdef UNUSED
 /* grammar allowing port variants */
