@@ -1,16 +1,23 @@
+/* $Id: common.h,v 1.12 2004/12/11 19:26:10 ellson Exp $ $Revision: 1.12 $ */
+/* vim:set shiftwidth=4 ts=8: */
+
+/**********************************************************
+*      This software is part of the graphviz package      *
+*                http://www.graphviz.org/                 *
+*                                                         *
+*            Copyright (c) 1994-2004 AT&T Corp.           *
+*                and is licensed under the                *
+*            Common Public License, Version 1.0           *
+*                      by AT&T Corp.                      *
+*                                                         *
+*        Information and Software Systems Research        *
+*              AT&T Research, Florham Park NJ             *
+**********************************************************/
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-/*
-    This software may only be used by you under license from AT&T Corp.
-    ("AT&T").  A copy of AT&T's Source Code Agreement is available at
-    AT&T's Internet website having the URL:
-    <http://www.research.att.com/sw/tools/graphviz/license/source.html>
-    If you received this software without first entering into a license
-    with AT&T, you have an infringing copy of this software and cannot use
-    it without violating AT&T's intellectual property rights.
-*/
 
 /* Lefteris Koutsofios - AT&T Bell Laboratories */
 
@@ -62,15 +69,15 @@ extern "C" {
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
 #endif
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
+#ifdef HAVE_SYS_SELECT_H
+#include <sys/select.h>
+#endif
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
@@ -80,7 +87,7 @@ extern "C" {
 #include <stdio.h>
 #include <setjmp.h>
 #include <ctype.h>
-                                                                                                            
+
 #ifdef FEATURE_WIN32
 #include <windows.h>
 #include <commdlg.h>
@@ -118,20 +125,20 @@ extern "C" {
 #define Strcmp(s1, s2) strcmp ((s1), (s2))
 #endif
 
-extern int warnflag;
-extern char *leftypath, *leftyoptions, *shellpath;
-extern jmp_buf exitljbuf;
-extern int idlerunmode;
-extern fd_set inputfds;
+    extern int warnflag;
+    extern char *leftypath, *leftyoptions, *shellpath;
+    extern jmp_buf exitljbuf;
+    extern int idlerunmode;
+    extern fd_set inputfds;
 
-int init (char *);
-void term (void);
-char *buildpath (char *, int);
-char *buildcommand (char *, char *, int, int, char *);
-void warning (char *, int, char *, char *, ...);
-void panic (char *, int, char *, char *, ...);
-void panic2 (char *, int, char *, char *, ...);
-#endif /* _COMMON_H */
+    int init(char *);
+    void term(void);
+    char *buildpath(char *, int);
+    char *buildcommand(char *, char *, int, int, char *);
+    void warning(char *, int, char *, char *, ...);
+    void panic(char *, int, char *, char *, ...);
+    void panic2(char *, int, char *, char *, ...);
+#endif				/* _COMMON_H */
 
 #ifdef __cplusplus
 }
